fake

package
v0.0.0-...-3af8a5e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package fake has the automatically generated clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FakeResourcePolicies

type FakeResourcePolicies struct {
	Fake *FakeSchedulingV1alpha1
	// contains filtered or unexported fields
}

FakeResourcePolicies implements ResourcePolicyInterface

func (*FakeResourcePolicies) Create

func (c *FakeResourcePolicies) Create(ctx context.Context, resourcePolicy *v1alpha1.ResourcePolicy, opts v1.CreateOptions) (result *v1alpha1.ResourcePolicy, err error)

Create takes the representation of a resourcePolicy and creates it. Returns the server's representation of the resourcePolicy, and an error, if there is any.

func (*FakeResourcePolicies) Delete

func (c *FakeResourcePolicies) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error

Delete takes name of the resourcePolicy and deletes it. Returns an error if one occurs.

func (*FakeResourcePolicies) DeleteCollection

func (c *FakeResourcePolicies) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeResourcePolicies) Get

func (c *FakeResourcePolicies) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.ResourcePolicy, err error)

Get takes name of the resourcePolicy, and returns the corresponding resourcePolicy object, and an error if there is any.

func (*FakeResourcePolicies) List

List takes label and field selectors, and returns the list of ResourcePolicies that match those selectors.

func (*FakeResourcePolicies) Patch

func (c *FakeResourcePolicies) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.ResourcePolicy, err error)

Patch applies the patch and returns the patched resourcePolicy.

func (*FakeResourcePolicies) Update

func (c *FakeResourcePolicies) Update(ctx context.Context, resourcePolicy *v1alpha1.ResourcePolicy, opts v1.UpdateOptions) (result *v1alpha1.ResourcePolicy, err error)

Update takes the representation of a resourcePolicy and updates it. Returns the server's representation of the resourcePolicy, and an error, if there is any.

func (*FakeResourcePolicies) UpdateStatus

func (c *FakeResourcePolicies) UpdateStatus(ctx context.Context, resourcePolicy *v1alpha1.ResourcePolicy, opts v1.UpdateOptions) (result *v1alpha1.ResourcePolicy, err error)

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeResourcePolicies) Watch

Watch returns a watch.Interface that watches the requested resourcePolicies.

type FakeSchedulingV1alpha1

type FakeSchedulingV1alpha1 struct {
	*testing.Fake
}

func (*FakeSchedulingV1alpha1) RESTClient

func (c *FakeSchedulingV1alpha1) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

func (*FakeSchedulingV1alpha1) ResourcePolicies

func (c *FakeSchedulingV1alpha1) ResourcePolicies(namespace string) v1alpha1.ResourcePolicyInterface

Jump to