v1alpha1

package
v0.0.0-...-a3139c5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 23, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ResourcePolicyLister

type ResourcePolicyLister interface {
	// List lists all ResourcePolicies in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*v1alpha1.ResourcePolicy, err error)
	// ResourcePolicies returns an object that can list and get ResourcePolicies.
	ResourcePolicies(namespace string) ResourcePolicyNamespaceLister
	ResourcePolicyListerExpansion
}

ResourcePolicyLister helps list ResourcePolicies. All objects returned here must be treated as read-only.

func NewResourcePolicyLister

func NewResourcePolicyLister(indexer cache.Indexer) ResourcePolicyLister

NewResourcePolicyLister returns a new ResourcePolicyLister.

type ResourcePolicyListerExpansion

type ResourcePolicyListerExpansion interface{}

ResourcePolicyListerExpansion allows custom methods to be added to ResourcePolicyLister.

type ResourcePolicyNamespaceLister

type ResourcePolicyNamespaceLister interface {
	// List lists all ResourcePolicies in the indexer for a given namespace.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*v1alpha1.ResourcePolicy, err error)
	// Get retrieves the ResourcePolicy from the indexer for a given namespace and name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*v1alpha1.ResourcePolicy, error)
	ResourcePolicyNamespaceListerExpansion
}

ResourcePolicyNamespaceLister helps list and get ResourcePolicies. All objects returned here must be treated as read-only.

type ResourcePolicyNamespaceListerExpansion

type ResourcePolicyNamespaceListerExpansion interface{}

ResourcePolicyNamespaceListerExpansion allows custom methods to be added to ResourcePolicyNamespaceLister.

Jump to